==> nxcomp-1.3.2-4.tar.gz: nxcomp/NXpack.h <==
/**************************************************************************/
/*                                                                        */
/* Copyright (c) 2001,2003 NoMachine, http://www.nomachine.com.           */
/*                                                                        */
/* NXPROXY, NX protocol compression and NX extensions to this software    */
/* are copyright of NoMachine. Redistribution and use of the present      */
/* software is allowed according to terms specified in the file LICENSE   */
/* which comes in the source distribution.                                */
/*                                                                        */
/* Check http://www.nomachine.com/licensing.html for applicability.       */
/*                                                                        */
/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
/*                                                                        */
/* All rights reserved.                                                   */
/*                                                                        */
/**************************************************************************/

#ifndef NXpack_H
#define NXpack_H

#ifdef __cplusplus
extern "C" {
#endif

#include <stdlib.h>

#define MASK_METHOD_LIMIT                       10

#define NO_MASK                                 0

#define MASK_8_COLORS                           1
#define MASK_64_COLORS                          2
#define MASK_256_COLORS                         3
#define MASK_512_COLORS                         4
#define MASK_4K_COLORS                          5
#define MASK_32K_COLORS                         6
#define MASK_64K_COLORS                         7
#define MASK_256K_COLORS                        8
#define MASK_2M_COLORS                          9
#define MASK_16M_COLORS                         10

#define PACK_METHOD_LIMIT                       128

#define NO_PACK                                 0

#define PACK_MASKED_8_COLORS                    1
#define PACK_MASKED_64_COLORS                   2
#define PACK_MASKED_256_COLORS                  3
#define PACK_MASKED_512_COLORS                  4
#define PACK_MASKED_4K_COLORS                   5
#define PACK_MASKED_32K_COLORS                  6
#define PACK_MASKED_64K_COLORS                  7
#define PACK_MASKED_256K_COLORS                 8
#define PACK_MASKED_2M_COLORS                   9
#define PACK_MASKED_16M_COLORS                  10

#define PACK_RAW_8_BITS                         3
#define PACK_RAW_16_BITS                        7
#define PACK_RAW_24_BITS                        10

#define PACK_COLORMAP_256_COLORS                11

#define PACK_RDP_PLAIN_256_COLORS               11
#define PACK_RDP_COMPRESSED_256_COLORS          12

#define PACK_RFB_HEXTILE                        13

#define PACK_RFB_TIGHT_PLAIN                    14
#define PACK_RFB_TIGHT_COMPRESSED               15

#define PACK_TIGHT_8_COLORS                     16
#define PACK_TIGHT_64_COLORS                    17
#define PACK_TIGHT_256_COLORS                   18
#define PACK_TIGHT_512_COLORS                   19
#define PACK_TIGHT_4K_COLORS                    20
#define PACK_TIGHT_32K_COLORS                   21
#define PACK_TIGHT_64K_COLORS                   22
#define PACK_TIGHT_256K_COLORS                  23
#define PACK_TIGHT_2M_COLORS                    24
#define PACK_TIGHT_16M_COLORS                   25

#define PACK_JPEG_8_COLORS                      26
#define PACK_JPEG_64_COLORS                     27
#define PACK_JPEG_256_COLORS                    28
#define PACK_JPEG_512_COLORS                    29
#define PACK_JPEG_4K_COLORS                     30
#define PACK_JPEG_32K_COLORS                    31
#define PACK_JPEG_64K_COLORS                    32
#define PACK_JPEG_256K_COLORS                   33
#define PACK_JPEG_2M_COLORS                     34
#define PACK_JPEG_16M_COLORS                    35

#define PACK_RDP_TEXT                           36

#define PACK_PNG_8_COLORS                       37
#define PACK_PNG_64_COLORS                      38
#define PACK_PNG_256_COLORS                     39
#define PACK_PNG_512_COLORS                     40
#define PACK_PNG_4K_COLORS                      41
#define PACK_PNG_32K_COLORS                     42
#define PACK_PNG_64K_COLORS                     43
#define PACK_PNG_256K_COLORS                    44
#define PACK_PNG_2M_COLORS                      45
#define PACK_PNG_16M_COLORS                     46

#define PACK_PNG_JPEG_8_COLORS                  47
#define PACK_PNG_JPEG_64_COLORS                 48
#define PACK_PNG_JPEG_256_COLORS                49
#define PACK_PNG_JPEG_512_COLORS                50
#define PACK_PNG_JPEG_4K_COLORS                 51
#define PACK_PNG_JPEG_32K_COLORS                52
#define PACK_PNG_JPEG_64K_COLORS                53
#define PACK_PNG_JPEG_256K_COLORS               54
#define PACK_PNG_JPEG_2M_COLORS                 55
#define PACK_PNG_JPEG_16M_COLORS                56

#define SPLIT_METHOD_LIMIT                      16

#define NO_SPLIT                                0

#define SPLIT_GEOMETRY_SMALL                    1
#define SPLIT_GEOMETRY_MEDIUM                   2
#define SPLIT_GEOMETRY_BIG                      3
#define SPLIT_GEOMETRY_HUGE                     4

typedef struct {
    unsigned int color_mask;
    unsigned int correction_mask;
    unsigned int white_threshold;
    unsigned int black_threshold;
} ColorMask;

typedef struct {
    int bitmap_width;
    int bitmap_height;
    int pixmap_width;
    int pixmap_height;
} SplitGeometry;

extern const ColorMask Mask8TrueColor;
extern const ColorMask Mask64TrueColor;
extern const ColorMask Mask512TrueColor;
extern const ColorMask Mask4KTrueColor;
extern const ColorMask Mask32KTrueColor;
extern const ColorMask Mask256KTrueColor;
extern const ColorMask Mask2MTrueColor;
extern const ColorMask Mask16MTrueColor;

const ColorMask *GetColorMask(unsigned int method);

const SplitGeometry *GetSplitGeometry(unsigned int method);

int GetBitsPerPixel(unsigned int method);

unsigned int SelectPackMethod(unsigned int method, int src_bits_per_pixel, int dst_bits_per_pixel);

#ifdef __cplusplus
}
#endif

#endif /* NXpack_H */

==> nxcomp-2.0.0-81.tar.gz: nxcomp/NXpack.h <==
/**************************************************************************/
/*                                                                        */
/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
/*                                                                        */
/* NXPROXY, NX protocol compression and NX extensions to this software    */
/* are copyright of NoMachine. Redistribution and use of the present      */
/* software is allowed according to terms specified in the file LICENSE   */
/* which comes in the source distribution.                                */
/*                                                                        */
/* Check http://www.nomachine.com/licensing.html for applicability.       */
/*                                                                        */
/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
/*                                                                        */
/* All rights reserved.                                                   */
/*                                                                        */
/**************************************************************************/

#ifndef NXpack_H
#define NXpack_H

#ifdef __cplusplus
extern "C" {
#endif

#define MASK_METHOD_LIMIT                       10

#define NO_MASK                                 0

#define MASK_8_COLORS                           1
#define MASK_64_COLORS                          2
#define MASK_256_COLORS                         3
#define MASK_512_COLORS                         4
#define MASK_4K_COLORS                          5
#define MASK_32K_COLORS                         6
#define MASK_64K_COLORS                         7
#define MASK_256K_COLORS                        8
#define MASK_2M_COLORS                          9
#define MASK_16M_COLORS                         10

#define PACK_METHOD_LIMIT                       128

#define NO_PACK                                 0

#define PACK_MASKED_8_COLORS                    1
#define PACK_MASKED_64_COLORS                   2
#define PACK_MASKED_256_COLORS                  3
#define PACK_MASKED_512_COLORS                  4
#define PACK_MASKED_4K_COLORS                   5
#define PACK_MASKED_32K_COLORS                  6
#define PACK_MASKED_64K_COLORS                  7
#define PACK_MASKED_256K_COLORS                 8
#define PACK_MASKED_2M_COLORS                   9
#define PACK_MASKED_16M_COLORS                  10

#define PACK_RAW_8_BITS                         3
#define PACK_RAW_16_BITS                        7
#define PACK_RAW_24_BITS                        10

#define PACK_COLORMAP_256_COLORS                11

#define PACK_RDP_PLAIN_256_COLORS               11
#define PACK_RDP_COMPRESSED_256_COLORS          12

#define PACK_RFB_HEXTILE                        13

#define PACK_RFB_TIGHT_PLAIN                    14
#define PACK_RFB_TIGHT_COMPRESSED               15

#define PACK_TIGHT_8_COLORS                     16
#define PACK_TIGHT_64_COLORS                    17
#define PACK_TIGHT_256_COLORS                   18
#define PACK_TIGHT_512_COLORS                   19
#define PACK_TIGHT_4K_COLORS                    20
#define PACK_TIGHT_32K_COLORS                   21
#define PACK_TIGHT_64K_COLORS                   22
#define PACK_TIGHT_256K_COLORS                  23
#define PACK_TIGHT_2M_COLORS                    24
#define PACK_TIGHT_16M_COLORS                   25

#define PACK_JPEG_8_COLORS                      26
#define PACK_JPEG_64_COLORS                     27
#define PACK_JPEG_256_COLORS                    28
#define PACK_JPEG_512_COLORS                    29
#define PACK_JPEG_4K_COLORS                     30
#define PACK_JPEG_32K_COLORS                    31
#define PACK_JPEG_64K_COLORS                    32
#define PACK_JPEG_256K_COLORS                   33
#define PACK_JPEG_2M_COLORS                     34
#define PACK_JPEG_16M_COLORS                    35

#define PACK_RDP_TEXT                           36

#define PACK_PNG_8_COLORS                       37
#define PACK_PNG_64_COLORS                      38
#define PACK_PNG_256_COLORS                     39
#define PACK_PNG_512_COLORS                     40
#define PACK_PNG_4K_COLORS                      41
#define PACK_PNG_32K_COLORS                     42
#define PACK_PNG_64K_COLORS                     43
#define PACK_PNG_256K_COLORS                    44
#define PACK_PNG_2M_COLORS                      45
#define PACK_PNG_16M_COLORS                     46

#define PACK_PNG_JPEG_8_COLORS                  47
#define PACK_PNG_JPEG_64_COLORS                 48
#define PACK_PNG_JPEG_256_COLORS                49
#define PACK_PNG_JPEG_512_COLORS                50
#define PACK_PNG_JPEG_4K_COLORS                 51
#define PACK_PNG_JPEG_32K_COLORS                52
#define PACK_PNG_JPEG_64K_COLORS                53
#define PACK_PNG_JPEG_256K_COLORS               54
#define PACK_PNG_JPEG_2M_COLORS                 55
#define PACK_PNG_JPEG_16M_COLORS                56

#define PACK_RDP_PLAIN_64K_COLORS               57
#define PACK_RDP_COMPRESSED_64K_COLORS          58
#define PACK_RDP_PLAIN_16M_COLORS               59
#define PACK_RDP_COMPRESSED_16M_COLORS          60
#define PACK_RDP_PLAIN_32K_COLORS               61
#define PACK_RDP_COMPRESSED_32K_COLORS          62

#define PACK_RGB_16M_COLORS                     63
#define PACK_RLE_16M_COLORS                     64

#define PACK_ALPHA                              65
#define PACK_COLORMAP                           66

#define SPLIT_METHOD_LIMIT                      16

#define NO_SPLIT                                0

#define SPLIT_GEOMETRY_SMALL                    1
#define SPLIT_GEOMETRY_MEDIUM                   2
#define SPLIT_GEOMETRY_BIG                      3
#define SPLIT_GEOMETRY_HUGE                     4

typedef struct
{
    unsigned int color_mask;
    unsigned int correction_mask;
    unsigned int white_threshold;
    unsigned int black_threshold;

} ColorMask;

typedef struct
{
    int bitmap_width;
    int bitmap_height;
    int pixmap_width;
    int pixmap_height;

} SplitGeometry;

extern const ColorMask Mask8TrueColor;
extern const ColorMask Mask64TrueColor;
extern const ColorMask Mask512TrueColor;
extern const ColorMask Mask4KTrueColor;
extern const ColorMask Mask32KTrueColor;
extern const ColorMask Mask256KTrueColor;
extern const ColorMask Mask2MTrueColor;
extern const ColorMask Mask16MTrueColor;

const ColorMask *MethodColorMask(unsigned int method);

const SplitGeometry *MethodSplitGeometry(unsigned int method);

int MethodBitsPerPixel(unsigned int method);

#ifdef __cplusplus
}
#endif

#endif /* NXpack_H */
